@@ -15,7 +15,7 @@ use Chrome::DevToolsProtocol::Transport;
 use Scalar::Util 'weaken', 'isweak';
 use Try::Tiny;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 our @CARP_NOT;
 
 =head1 NAME
@@ -656,10 +656,11 @@ sub callFunctionOn( $self, $function, %options ) {
 
 =cut
 
-sub evaluate( $self, $string ) {
+sub evaluate( $self, $string, %options ) {
     $self->send_message('Runtime.evaluate',
         expression => $string,
-        returnByValue => JSON::true
+        returnByValue => JSON::true,
+        %options
     )
 };
 
