@@ -2,7 +2,7 @@ package HTTP::Cookies::Chrome;
 use strict;
 use Carp qw[croak];
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 our @CARP_NOT;
 
 use Moo 2;
@@ -83,8 +83,6 @@ sub load($self,$driver = $self->driver) {
     $self->clear();
     local $self->{_loading} = 1;
     for my $c (@$cookies) {
-        use Data::Dumper;
-        warn Dumper $c;
         $self->set_cookie(
             1,
             $c->{name},
